EXPORTS
	__7CTFStubi @ 1 NONAME R3UNUSED ; CTFStub::CTFStub(int)
	AddL__20CTFATestSuiteAdapterR15MTFATestAdapter @ 2 NONAME R3UNUSED ; CTFATestSuiteAdapter::AddL(MTFATestAdapter &)
	AddStubTestCaseL__18CTFTestCaseWrapperR15MTFStubTestCase @ 3 NONAME R3UNUSED ; CTFTestCaseWrapper::AddStubTestCaseL(MTFStubTestCase &)
	At__13CTFATestSuitei @ 4 NONAME R3UNUSED ; CTFATestSuite::At(int)
	CallLocalStubL__10CTFFactoryiPvN32 @ 5 NONAME ; CTFFactory::CallLocalStubL(int, void *, void *, void *, void *)
	CallRemoteStubL__10CTFFactoryiPvN32 @ 6 NONAME ; CTFFactory::CallRemoteStubL(int, void *, void *, void *, void *)
	CallRemoteStubL__10CTFFactoryiPvN32R14TRequestStatus @ 7 NONAME ; CTFFactory::CallRemoteStubL(int, void *, void *, void *, void *, TRequestStatus &)
	CompleteTest__15CTFStubTestCasei @ 8 NONAME R3UNUSED ; CTFStubTestCase::CompleteTest(int)
	ConstructL__14CTFAEntryPoint @ 9 NONAME R3UNUSED ; CTFAEntryPoint::ConstructL(void)
	Count__C13CTFATestSuite @ 10 NONAME R3UNUSED ; CTFATestSuite::Count(void) const
	CurrentTestCaseID__7CTFStub @ 11 NONAME R3UNUSED ; CTFStub::CurrentTestCaseID(void)
	CurrentTestCase__7CTFStub @ 12 NONAME R3UNUSED ; CTFStub::CurrentTestCase(void)
	DoSetActive__14CTFAActiveTest @ 13 NONAME R3UNUSED ; CTFAActiveTest::DoSetActive(void)
	Environment__8CTFATest @ 14 NONAME R3UNUSED ; CTFATest::Environment(void)
	Factory__19CTFATestEnvironment @ 15 NONAME R3UNUSED ; CTFATestEnvironment::Factory(void)
	Id__C12CTFATestCase @ 16 NONAME R3UNUSED ; CTFATestCase::Id(void) const
	IsComplete__15CTFStubTestCase @ 17 NONAME R3UNUSED ; CTFStubTestCase::IsComplete(void)
	Logger__15CTFStubTestCase @ 18 NONAME R3UNUSED ; CTFStubTestCase::Logger(void)
	Logger__19CTFATestEnvironment @ 19 NONAME R3UNUSED ; CTFATestEnvironment::Logger(void)
	Name__C8CTFATest @ 20 NONAME R3UNUSED ; CTFATest::Name(void) const
	NewL__13CTFATestTimerR14MTFAActiveTest @ 21 NONAME R3UNUSED ; CTFATestTimer::NewL(MTFAActiveTest &)
	RootSuiteAdapter__14CTFAEntryPoint @ 22 NONAME R3UNUSED ; CTFAEntryPoint::RootSuiteAdapter(void)
	RunOnStartup__C12CTFATestCase @ 23 NONAME R3UNUSED ; CTFATestCase::RunOnStartup(void) const
	SetCallback__15CTFStubTestCaseR20MTFTestCaseInterface @ 24 NONAME R3UNUSED ; CTFStubTestCase::SetCallback(MTFTestCaseInterface &)
	SetEnvironment__18CTFTestCaseWrapperR19CTFATestEnvironment @ 25 NONAME R3UNUSED ; CTFTestCaseWrapper::SetEnvironment(CTFATestEnvironment &)
	SetEnvironment__19CTFTestCaseRepeaterR19CTFATestEnvironment @ 26 NONAME R3UNUSED ; CTFTestCaseRepeater::SetEnvironment(CTFATestEnvironment &)
	SetEnvironment__8CTFATestR19CTFATestEnvironment @ 27 NONAME R3UNUSED ; CTFATest::SetEnvironment(CTFATestEnvironment &)
	SetRunOnStartup__12CTFATestCasei @ 28 NONAME R3UNUSED ; CTFATestCase::SetRunOnStartup(int)
	SetStub__15CTFStubTestCaseR7CTFStub @ 29 NONAME R3UNUSED ; CTFStubTestCase::SetStub(CTFStub &)
	SetTimeout__12CTFATestCasei @ 30 NONAME R3UNUSED ; CTFATestCase::SetTimeout(int)
	SetupL__15CTFStubTestCase @ 31 NONAME R3UNUSED ; CTFStubTestCase::SetupL(void)
	Status__14CTFAActiveTest @ 32 NONAME R3UNUSED ; CTFAActiveTest::Status(void)
	Stub__10CTFFactoryi @ 33 NONAME R3UNUSED ; CTFFactory::Stub(int)
	Timeout__C12CTFATestCase @ 34 NONAME R3UNUSED ; CTFATestCase::Timeout(void) const
	Type__15CTFStubTestCase @ 35 NONAME R3UNUSED ; CTFStubTestCase::Type(void)
	Type__C12CTFATestCase @ 36 NONAME R3UNUSED ; CTFATestCase::Type(void) const
	Type__C13CTFATestSuite @ 37 NONAME R3UNUSED ; CTFATestSuite::Type(void) const
	Type__C19CTFATestCaseAdapter @ 38 NONAME R3UNUSED ; CTFATestCaseAdapter::Type(void) const
	Type__C20CTFATestSuiteAdapter @ 39 NONAME R3UNUSED ; CTFATestSuiteAdapter::Type(void) const
	"_._11CTFATestLog" @ 40 NONAME R3UNUSED ; CTFATestLog::~CTFATestLog(void)
	"_._12CTFATestCase" @ 41 NONAME R3UNUSED ; CTFATestCase::~CTFATestCase(void)
	"_._13CTFATestSuite" @ 42 NONAME R3UNUSED ; CTFATestSuite::~CTFATestSuite(void)
	"_._13CTFATestTimer" @ 43 NONAME R3UNUSED ; CTFATestTimer::~CTFATestTimer(void)
	"_._13CTFRemoteStub" @ 44 NONAME R3UNUSED ; CTFRemoteStub::~CTFRemoteStub(void)
	"_._14CTFAActiveTest" @ 45 NONAME R3UNUSED ; CTFAActiveTest::~CTFAActiveTest(void)
	"_._14CTFAEntryPoint" @ 46 NONAME R3UNUSED ; CTFAEntryPoint::~CTFAEntryPoint(void)
	"_._14MTFAActiveTest" @ 47 NONAME R3UNUSED ; MTFAActiveTest::~MTFAActiveTest(void)
	"_._15CTFStubTestCase" @ 48 NONAME R3UNUSED ; CTFStubTestCase::~CTFStubTestCase(void)
	"_._15MTFATestAdapter" @ 49 NONAME R3UNUSED ; MTFATestAdapter::~MTFATestAdapter(void)
	"_._19CTFATestCaseAdapter" @ 50 NONAME R3UNUSED ; CTFATestCaseAdapter::~CTFATestCaseAdapter(void)
	"_._19CTFATestEnvironment" @ 51 NONAME R3UNUSED ; CTFATestEnvironment::~CTFATestEnvironment(void)
	"_._19MTFATestCaseAdapter" @ 52 NONAME R3UNUSED ; MTFATestCaseAdapter::~MTFATestCaseAdapter(void)
	"_._20CTFATestSuiteAdapter" @ 53 NONAME R3UNUSED ; CTFATestSuiteAdapter::~CTFATestSuiteAdapter(void)
	"_._20CTFStubTestCaseParam" @ 54 NONAME R3UNUSED ; CTFStubTestCaseParam::~CTFStubTestCaseParam(void)
	"_._20MTFATestSuiteAdapter" @ 55 NONAME R3UNUSED ; MTFATestSuiteAdapter::~MTFATestSuiteAdapter(void)
	"_._7CTFStub" @ 56 NONAME R3UNUSED ; CTFStub::~CTFStub(void)
	__11CTFATestLog @ 57 NONAME R3UNUSED ; CTFATestLog::CTFATestLog(void)
	__12CTFATestCaseiRC7TDesC16 @ 58 NONAME R3UNUSED ; CTFATestCase::CTFATestCase(int, TDesC16 const &)
	__13CTFATestSuiteRC7TDesC16 @ 59 NONAME R3UNUSED ; CTFATestSuite::CTFATestSuite(TDesC16 const &)
	__13CTFRemoteStubi @ 60 NONAME R3UNUSED ; CTFRemoteStub::CTFRemoteStub(int)
	__14CTFAActiveTestR14MTFAActiveTest @ 61 NONAME R3UNUSED ; CTFAActiveTest::CTFAActiveTest(MTFAActiveTest &)
	__14CTFAEntryPoint @ 62 NONAME R3UNUSED ; CTFAEntryPoint::CTFAEntryPoint(void)
	__14MTFAActiveTest @ 63 NONAME R3UNUSED ; MTFAActiveTest::MTFAActiveTest(void)
	__15CTFStubTestCasei @ 64 NONAME R3UNUSED ; CTFStubTestCase::CTFStubTestCase(int)
	__15MTFATestAdapter @ 65 NONAME R3UNUSED ; MTFATestAdapter::MTFATestAdapter(void)
	__18CTFTestCaseWrapperiRC7TDesC16 @ 66 NONAME R3UNUSED ; CTFTestCaseWrapper::CTFTestCaseWrapper(int, TDesC16 const &)
	__19CTFATestCaseAdapterR12CTFATestCase @ 67 NONAME R3UNUSED ; CTFATestCaseAdapter::CTFATestCaseAdapter(CTFATestCase &)
	__19CTFATestEnvironmentR11CTFATestLog @ 68 NONAME R3UNUSED ; CTFATestEnvironment::CTFATestEnvironment(CTFATestLog &)
	__19CTFTestCaseRepeateriRC7TDesC16P13CTFATestSuiteii @ 69 NONAME ; CTFTestCaseRepeater::CTFTestCaseRepeater(int, TDesC16 const &, CTFATestSuite *, int, int)
	__19MTFATestCaseAdapter @ 70 NONAME R3UNUSED ; MTFATestCaseAdapter::MTFATestCaseAdapter(void)
	__20CTFATestSuiteAdapterR13CTFATestSuiteP14CTFAEntryPoint @ 71 NONAME R3UNUSED ; CTFATestSuiteAdapter::CTFATestSuiteAdapter(CTFATestSuite &, CTFAEntryPoint *)
	__20CTFStubTestCaseParam @ 72 NONAME R3UNUSED ; CTFStubTestCaseParam::CTFStubTestCaseParam(void)
	__20MTFATestSuiteAdapter @ 73 NONAME R3UNUSED ; MTFATestSuiteAdapter::MTFATestSuiteAdapter(void)
	AddL__13CTFATestSuiteRC8CTFATest @ 74 NONAME R3UNUSED ; CTFATestSuite::AddL(CTFATest const &)
	Flags__C12CTFATestCase @ 75 NONAME R3UNUSED ; CTFATestCase::Flags(void) const
	SetFlags__12CTFATestCaseUl @ 76 NONAME R3UNUSED ; CTFATestCase::SetFlags(unsigned long)
	SetEnvironment__12CTFATestCaseR19CTFATestEnvironment @ 77 NONAME R3UNUSED ; CTFATestCase::SetEnvironment(CTFATestEnvironment &)
	SetTestCaseFlags__19CTFATestEnvironmentUl @ 78 NONAME R3UNUSED ; CTFATestEnvironment::SetTestCaseFlags(unsigned long)

